#
# spec file for package libuv
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define somajor 1
Name:           libuv
Version:        1.6.1
Release:        6.5
Summary:        Cross-platform asychronous I/O
License:        MIT
Group:          Development/Libraries/C and C++
Url:            https://github.com/libuv/libuv
Source0:        https://github.com/libuv/libuv/archive/v%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
libuv is a multi-platform support library with a focus on asynchronous I/O. It
was primarily developed for use by Node.js, but it's also used by Mozilla's
Rust language, Luvit, Julia, pyuv, and others.

%package     -n libuv%{somajor}
Summary:        Cross-platform asychronous I/O
Group:          System/Libraries

%description -n libuv%{somajor}
libuv is a multi-platform support library with a focus on asynchronous I/O. It
was primarily developed for use by Node.js, but it's also used by Mozilla's
Rust language, Luvit, Julia, pyuv, and others.

%package        devel
Summary:        Development libraries for libuv
Group:          Development/Libraries/C and C++
BuildRequires:  glibc-devel
Requires:       libuv%{somajor} = %{version}

%description    devel
Development files for libuv

libuv is a multi-platform support library with a focus on asynchronous I/O. It
was primarily developed for use by Node.js, but it's also used by Mozilla's
Rust language, Luvit, Julia, pyuv, and others.

%prep
%setup -q
sh autogen.sh

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
# Tests sadly fail
#make %{?_smp_mflags} check

%post -n libuv%{somajor} -p /sbin/ldconfig

%postun -n libuv%{somajor} -p /sbin/ldconfig

%files -n libuv%{somajor}
%defattr(-,root,root)
%{_libdir}/libuv.so.%{somajor}*

%files devel
%defattr(-,root,root)
%doc AUTHORS CONTRIBUTING.md ChangeLog LICENSE README.md
%{_libdir}/libuv.so
%{_includedir}/uv*
%{_libdir}/pkgconfig/libuv.pc

%changelog
* Wed Aug  5 2015 mpluskal@suse.com
- Update to 1.6.1
  * unix: handle invalid _SC_GETPW_R_SIZE_MAX values (cjihrig)
- Changes for 1.6.0
  * aix: fix setsockopt for multicast options (Michael)
  * unix: don't block for io if any io handle is primed (Saúl
    Ibarra Corretgé)
  * windows: MSVC 2015 has snprintf() (Rui Abreu Ferreira)
  * windows: Add VS2015 support to vcbuild.bat (Jason Williams)
  * doc: fix typo in tcp.rst (Igor Soarez)
  * linux: work around epoll bug in kernels < 2.6.37 (Ben
    Noordhuis)
  * unix,win: add uv_os_homedir() (cjihrig)
  * stream: fix `select()` race condition (Fedor Indutny)
  * unix: prevent infinite loop in uv__run_pending (Saúl Ibarra
    Corretgé)
  * unix: make sure UDP send callbacks are asynchronous (Saúl
    Ibarra Corretgé)
  * test: fix `platform_output` netmask printing. (Andrew Paprocki)
  * aix: add ahafs autoconf detection and README notes (Andrew
    Paprocki)
  * core: add ability to customize memory allocator (Saúl Ibarra
    Corretgé)
- Changes for 1.5.0
  * doc: clarify that the thread pool primites are not thread safe
    (Andrius Bentkus)
  * aix: always deregister closing fds from epoll (Michael)
  * unix: fix glibc-2.20+ macro incompatibility (Massimiliano
    Torromeo)
  * doc: add Sphinx plugin for generating links to man pages
    (Saúl Ibarra Corretgé)
  * doc: link system and library calls to man pages (Saúl
    Ibarra Corretgé)
  * doc: document uv_getnameinfo_t.{host|service} (Saúl Ibarra
    Corretgé)
  * build: update the location of gyp (Stephen von Takach)
  * win: name all anonymous structs and unions (TomCrypto)
  * linux: work around epoll bug in kernels 3.10-3.19 (Ben
    Noordhuis)
  * darwin: fix size calculation in select() fallback (Ole
    André Vadla Ravnås)
  * solaris: fix setsockopt for multicast options (Julien
    Gilli)
  * test: fix race condition in multithreaded test (Ben Noordhuis)
  * doc: fix long lines in tty.rst (Ben Noordhuis)
  * test: use UV_TTY_MODE_* values in tty test (Ben Noordhuis)
  * unix: don't clobber errno in uv_tty_reset_mode() (Ben
    Noordhuis)
  * unix: reject non-tty fds in uv_tty_init() (Ben Noordhuis)
  * win: fix pipe blocking writes (Alexis Campailla)
  * build: fix cross-compiling for iOS (Steven Kabbes)
  * win: remove unnecessary malloc.h
  * include: use `extern "c++"` for defining C++ code (Kazuho Oku)
  * unix: reap child on execvp() failure (Ryan Phillips)
  * windows: fix handle leak on EMFILE (Brian Green)
  * test: fix tty_file, close handle if initialized (Saúl Ibarra
    Corretgé)
  * doc: clarify what uv_*_open accepts (Saúl Ibarra Corretgé)
  * doc: clarify that we don't maintain external doc resources
    (Saúl Ibarra Corretgé)
  * build: add documentation for ninja support (Devchandra
    Meetei Leishangthem)
  * doc: document uv_buf_t members (Corey Farrell)
  * linux: fix epoll_pwait() fallback on arm64 (Ben Noordhuis)
  * android: fix compilation warning (Saúl Ibarra Corretgé)
  * unix: don't close the fds we just setup (Sam Roberts)
  * test: spawn child replacing std{out,err} to stderr
  * unix: fix swapping fds order in uv_spawn
  * unix: fix potential bug if dup2 fails in uv_spawn
  * test: remove LOG and LOGF variadic macros
  * win: fix uv_fs_access on directories
  * win: fix of double free in uv_uptime
  * unix: open "/dev/null" instead of "/" for emfile_fd
  * docs: add some missing words
  * unix: clean up uv_fs_open() O_CLOEXEC logic
  * build: set SONAME for shared library in uv.gyp
  * windows: define snprintf replacement as inline instead of static
  * win: fix unlink of readonly files
  * doc: fix uv_run(UV_RUN_DEFAULT) description
  * linux: intercept syscall when running under memory sanitizer
  * aix: fix uv_interface_addresses return value
  * windows: defer reporting TCP write failure until next tick
  * test: add test for deferred TCP write failure
* Mon Mar  2 2015 tchvatal@suse.com
- Version bump to 1.4.2:
  * stream: ignore EINVAL for SO_OOBINLINE on OS X (Fedor Indutny)
  * win: don't use inline keyword in thread.c (Ben Noordhuis)  * windows: fix
  * setting dirent types on uv_fs_scandir_next (Saúl Ibarra Corretgé)  *
  * unix,windows: make uv_thread_create() return errno (Ben Noordhuis)  * tty:
  * fix build for SmartOS (Julien Gilli)  * unix: fix for uv_async data race
  * (Michael Penick)  * unix, windows: map EHOSTDOWN errno (Ben Noordhuis)  *
  * stream: use SO_OOBINLINE on OS X (Fedor Indutny)
* Thu Feb 12 2015 tchvatal@suse.com
- Version bump to 1.4.0 which is the latest release
- Cleanup with the spec cleaner
- Try to enable tests and they currently fail
* Mon Sep 15 2014 00:00:00 UTC - daxim@cpan.org
- update to v0.11.29
* Mon Aug 11 2014 00:00:00 UTC - daxim@cpan.org
- update to v0.11.28
* Wed Apr 30 2014 00:00:00 UTC - dmacvicar@suse.de
- update to 0.11.24
- install pkg-config file
* Sun Apr 13 2014 dmitry_r@opensuse.org
- Update to version 0.11.23
  * bug fixes
* Mon Mar 10 2014 daxim@cpan.org
- update to v0.11.21
* Fri Jan 31 2014 daxim@cpan.org
- initial packaging of v0.11.19
